pub enum SeparationColorant {
NoColorant,
AllColorants,
Custom(String),
}Expand description
What colorant to use for colors in this space.
Variants
NoColorant
Don’t apply colorant at all. Sometimes used to indicate other production info, such as cuts.
AllColorants
Apply the same amount of each available colorants.
Custom(String)
Specify a colorant name.