Module error

Module error 

Error handling.

There are a lot of things that can go wrong when writing a PDF, like for example when invalid fonts are provided. This module provides the basic error types krilla uses.

Enums

KrillaError
An error in krilla.
LimitError
A limit imposed by the selected PDF version.

Type Aliases

KrillaResult
A wrapper type for krilla errors.