pub struct RadialGradient {
pub fx: f32,
pub fy: f32,
pub fr: f32,
pub cx: f32,
pub cy: f32,
pub cr: f32,
pub transform: Transform,
pub spread_method: SpreadMethod,
pub stops: Vec<Stop>,
pub anti_alias: bool,
}Expand description
A radial gradient.
Fields
fx: f32The x coordinate of the start circle.
fy: f32The y coordinate of the start circle.
fr: f32The radius of the start circle.
cx: f32The x coordinate of the end circle.
cy: f32The y coordinate of the end circle.
cr: f32The radius of the end circle.
transform: TransformA transform that should be applied to the radial gradient.
spread_method: SpreadMethodThe spread method of the radial gradient.
Note: The spread methods Repeat/Reflect are currently not supported
for radial gradients, and will fall back to Pad.
stops: Vec<Stop>The color stops of the radial gradient.
Note that all stops need to be in the same color space.
anti_alias: boolWhether the gradient should be anti-aliased.