WritingMode

Enum WritingMode 

pub enum WritingMode {
    LrTb,
    RlTb,
    TbRl,
}
The directions of layout progression for packing of ILSEs (inline progression) and stacking of BLSEs (block progression). The specified layout directions shall apply to the given structure element and all of its descendants to any level of nesting.

Default value: WritingMode::LrTb.

Variants



LrTb

Inline progression from left to right; block progression from top to bottom. This is the typical writing mode for Western writing systems.



RlTb

Inline progression from right to left; block progression from top to bottom. This is the typical writing mode for Arabic and Hebrew writing systems.



TbRl

Inline progression from top to bottom; block progression from right to left. This is the typical writing mode for Chinese and Japanese writing systems.